6. formfactor (ff) — Jscatter 1.2.4 documentation

# 6. formfactor (ff)

## 6.1. Form Factors

General

`beaucage` |
`genGuinier` |
`guinier` |
`guinierPorod` |
`guinierPorod3d` |
`gaussianChain` |
`ringPolymer` |
`wormlikeChain` |

Sphere, Ellipsoid, Cylinder, Cube, CoreShell,..

`sphere` |
`ellipsoid` |
`cylinder` |
`disc` |
`cuboid` |
`superball` |
`sphereCoreShell` |
`sphereFuzzySurface` |
`sphereGaussianCorona` |
`sphereCoreShellGaussianCorona` |
`inhomogeneousSphere` |
`fuzzyCylinder` |

Multi shell models

`multilayer` |
`multiShellSphere` |
`multiShellEllipsoid` |
`multiShellDisc` |
`multiShellCylinder` |
`multilamellarVesicles` |

Other

`pearlNecklace` |
`linearPearls` |
`teubnerStrey` |
`ellipsoidFilledCylinder` |
`decoratedCoreShell` |

## 6.2. Cloud of scatterers

`jscatter.cloudscattering.cloudScattering` |
`jscatter.cloudscattering.orientedCloudScattering` |